# Slot: defining_slots


The combination of is_a plus defining slots form a genus-differentia definition, or the set of necessary and sufficient conditions that can be transformed into an OWL equivalence axiom

URI: [http://w3id.org/biolink/biolinkml/meta/defining_slots](slot_uri)
## Domain and Range

[ClassDefinition](ClassDefinition.md) -><sub>opt</sub> [[SlotDefinition](SlotDefinition.md)]
## Inheritance

## Children

## Used by

 * [ClassDefinition](ClassDefinition.md)
